MethodChannelAllBluetooth class final

An implementation of AllBluetoothPlatform that uses method channels.

Inheritance

Constructors

MethodChannelAllBluetooth()

Properties

bluetoothChangeEvent → EventChannel
final
connectionChange → EventChannel
final
discoverDevices → Stream<BluetoothDevice>
no setteroverride
foundDeviceEvent → EventChannel
final
hashCode → int
The hash code for this object.
no setterinherited
listenForConnection → Stream<ConnectionResult>
no setteroverride
listenForData → Stream<String?>
no setteroverride
listenToBluetoothState → Stream<bool>
no setteroverride
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sendReceiveEvent → EventChannel
final

Methods

closeConnection() → Future<void>
override
connectToDevice(String address) → Future<void>
override
getBondedDevices() → Future<List<BluetoothDevice>>
override
isBluetoothOn() → Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sendMessage(String message) → Future<bool>
override
startBluetoothServer({int? timeout}) → Future<void>
override
startDiscovery() → Future<void>
override
stopDiscovery() → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited